import request from '@/router/axios';

export const getList = (current, size, params) => {
  return request({
    url: '/api/iot-system/tenant/list',
    method: 'get',
    params: {
      ...params,
      current,
      size,
    }
  })
}

export const getPage = (current, size, params) => {
  return request({
    url: '/api/iot-system/tenant/pageExceptAdmin',
    method: 'get',
    params: {
      ...params,
      current,
      size,
    }
  })
}

export const getDetail = (id) => {
  return request({
    url: '/api/iot-system/tenant/detail',
    method: 'get',
    params: {
      id
    }
  })
}

export const remove = (id) => {
  return request({
    url: '/api/iot-system/tenant/remove',
    method: 'post',
    params: {
      id,
    }
  })
}

export const add = (row) => {
  return request({
    url: '/api/iot-system/tenant/submit',
    method: 'post',
    data: row
  })
}

export const update = (row) => {
  return request({
    url: '/api/iot-system/tenant/submit',
    method: 'post',
    data: row
  })
}

export const setting = (ids, form) => {
  return request({
    url: '/api/iot-system/tenant/setting',
    method: 'post',
    params: {
      ...form,
      ids
    }
  })
}

export const datasource = (tenantId, datasourceId) => {
  return request({
    url: '/api/iot-system/tenant/datasource',
    method: 'post',
    params: {
      tenantId,
      datasourceId
    }
  })
}

export const info = (domain) => {
  return request({
    url: '/api/iot-system/tenant/info',
    method: 'get',
    params: {
      domain
    }
  })
}

//选中的api列表
export const page = (query) => {
  return request({
    url: '/api/iot-core/tenant/api/page',
    method: 'get',
    params: query
  })
}

//查询出未绑定租户的产品api
export const noselect = (query) => {
  return request({
    url: '/api/iot-core/tenant/api/select',
    method: 'get',
    params: query
  })
}
//租户绑定产品api
export const bind = (data) => {
  return request({
    url: '/api/iot-core/tenant/api/bind',
    method: 'post',
    data
  })
}
//租户解绑产品api
export const unbind = (id) => {
  return request({
    url: '/api/iot-core/tenant/api/unbind?id='+id,
    method: 'post',
    id
  })
}
//禁用接口
export const disable = (id) => {
  return request({
    url: '/api/iot-core/tenant/api/disable?id='+id,
    method: 'post',
    id
  })
}
//启用接口
export const enable = (id) => {
  return request({
    url: '/api/iot-core/tenant/api/enable?id='+id,
    method: 'post',
    id
  })
}

//一级路由
export const firstR = (query) => {
  return request({
    url: '/api/iot-core/source/api/select',
    method: 'get',
    params:query
  })
}
//配置一级路由
export const setRoute = (data) => {
  return request({
    url: '/api/iot-core/tenant/api/setRoute?id='+data.id+"&sourceApiIds="+data.sourceApiIds,
    method: 'post',
    data
  })
}

//配置价格
export const setPrice = (obj) => {
  return request({
    url: '/api/iot-core/tenant/api/setPrice',
    method: 'post',
    params:{
      ...obj
    }
  })
}
//设置IP白名单
export const setIpWhiteList = (obj) => {
  return request({
    url: '/api/iot-system/tenant/setIpWhiteList',
    method: 'post',
    params:{
      ...obj
    }
  })
}
//充值
export const charge = (obj) => {
  return request({
    url: '/api/iot-system/tenant/charge',
    method: 'post',
    params:{
      ...obj
    }
  })
}
//设置授信额度
export const setCreditAmount = (obj) => {
  return request({
    url: '/api/iot-system/tenant/setCreditAmount',
    method: 'post',
    params:{
      ...obj
    }
  })
}
//设置api权限
export const enables = (obj) => {
  return request({
    url: '/api/iot-system/tenant/openApi/enable',
    method: 'post',
    params:{
      ...obj
    }
  })
}
//设置缓存
export const cache = (obj) => {
  return request({
    url: '/api/iot-system/tenant/cache/enable',
    method: 'post',
    params:{
      ...obj
    }
  })
}
